@@ -4,16 +4,18 @@ import axios from 'axios';
 
 function App() {
   const backend_url = 'http://localhost:5000'
-  const data = "";
+  let data = "";
+
+  hitAPI = () => {
+    axios.get(backend_url)
+      .then(res => {
+        console.log(res.data)
+        data = res.data
+      })
+    }
 
   useEffect(() => {
-    setTimeout(() => {
-      axios.get(backend_url)
-      .then(res => {
-        console.log(res)
-        data = res
-      })
-    }, 1000);
+      hitAPI();
   }, []);
 
 
